@@ -64,6 +64,7 @@ public:
         Takeaway,
         Socket,
         OpeningHours,
+        AvailableVehicles,
         Fee,
         Authentication,
         BicycleParking,
@@ -89,6 +90,7 @@ public:
         OperatorName,
         Network,
         OperatorWikipedia,
+        RemainingRange,
         DebugLink,
         DebugKey,
     };
