@@ -5,6 +5,7 @@
 */
 
 #include "mapcssstyle.h"
+#include "mapcssstyle_p.h"
 #include "mapcssparser.h"
 #include "mapcssresult_p.h"
 #include "mapcssrule_p.h"
@@ -15,14 +16,17 @@
 
 using namespace KOSMIndoorMap;
 
-MapCSSStyle::MapCSSStyle() = default;
+MapCSSStyle::MapCSSStyle()
+    : d(new MapCSSStylePrivate)
+{}
+
 MapCSSStyle::MapCSSStyle(MapCSSStyle&&) = default;
 MapCSSStyle::~MapCSSStyle() = default;
 MapCSSStyle& MapCSSStyle::operator=(MapCSSStyle&&) = default;
 
 void MapCSSStyle::compile(const OSM::DataSet &dataSet)
 {
-    for (const auto &rule : m_rules) {
+    for (const auto &rule : d->m_rules) {
         rule->compile(dataSet);
     }
 }
@@ -30,7 +34,7 @@ void MapCSSStyle::compile(const OSM::DataSet &dataSet)
 void MapCSSStyle::evaluate(const MapCSSState &state, MapCSSResult &result) const
 {
     result.clear();
-    for (const auto &rule : m_rules) {
+    for (const auto &rule : d->m_rules) {
         rule->evaluate(state, result);
     }
 }
@@ -38,14 +42,14 @@ void MapCSSStyle::evaluate(const MapCSSState &state, MapCSSResult &result) const
 void MapCSSStyle::evaluateCanvas(const MapCSSState &state, MapCSSResult &result) const
 {
     result.clear();
-    for (const auto &rule : m_rules) {
+    for (const auto &rule : d->m_rules) {
         rule->evaluateCanvas(state, result);
     }
 }
 
 void MapCSSStyle::write(QIODevice *out) const
 {
-    for (const auto &rule : m_rules) {
+    for (const auto &rule : d->m_rules) {
         rule->write(out);
     }
 }
